@@ -21,7 +21,8 @@
 #ifndef APPLICATION_H
 #define APPLICATION_H
 
-#include <kontactinterface/pimuniqueapplication.h>
+#include <KontactInterface/PimUniqueApplication>
+
 class KNotesApp;
 
 class Application : public KontactInterface::PimUniqueApplication
@@ -33,7 +34,7 @@ public:
     int activate(const QStringList &args, const QString &workingDir) override;
 
 private:
-    KNotesApp *mMainWindow;
+    KNotesApp *mMainWindow = nullptr;
 };
 
 #endif
